/*****************************************************************************
*  Stubs for 4.1 Drawing library.
*
****************************************************************************
*
*  The following is a complete list of the functions provided by the
*  Daylight 4.1 drawing library.  The functions marked with -> are
*  actually called by the Depict Toolkit and form the minimal set that
*  must be implemented to form a valid drawing library for use with this
*  Toolkit.  The last three functions are provided in dl_vectorlabels.o.
*  The stdcolor entries are provided in dy_stdcolor.o.
*
*
*    dl_beginscreen ..... called before drawing begins
*    dl_endscreen ....... called when drawing complete
* -> dl_flush ........... called when output buffer should be flushed
*
*    dl_setcellcount .... sets desired number of cells per drawing
*    dl_setcellrc ....... sets rows/cols in grid (setcallcount alternative)
*    dl_cellcount ....... returns actual number of cells
*    dl_cellrows ........ returns current number of rows in cell grid
*    dl_cellcols ........ returns current number of cols in cell grid
*
*    dl_setcell ......... sets current number of cell
*    dl_cell ............ return current cell number
*  
* -> dl_setga ........... sets current ga (e.g. DL_GA_DEFAULT)
*    dl_ga .............. returns current ga
*
*    dl_colormode ....... returns color mode (e.g. DL_COLORMODE_MONOCHROME)
*
*    dl_setlinewidth .... sets line width (e.g. DL_LINEWIDTH_THIN)
*    dl_setlinestyle .... sets line style (e.g. DL_LINESTYLE_SOLID)
*  
*    dl_setpixels ....... sets actual window size in pixels
*    dl_pixels .......... returns actual window size
* -> dl_paspect ......... returns physical aspect ratio
*
*    dl_setbounds ....... sets drawing bounds to given limits
* -> dl_fitbounds ....... sets drawing bounds to fit limits at 1:1 aspect
*    dl_fixbounds ....... sets/unsets whether setbounds/fixbounds is active
* -> dl_bounds .......... returns current drawing bounds
* 
* -> dl_moveto .......... (re)sets current drawing point
* -> dl_drawto .......... draws from current point to given point
*    dl_drawbox ......... draws a rectangle
* -> dl_drawoval ........ draws an oval
*
* .. dl_labelbounds ..... returns bounds of text label of given size.
* .. dl_drawlabel ....... draws text label of given size
* .. dl_fitlabel ........ draws text label in rectangle of given size
*
*    dl_stdcolor_count .. returns the number of standard colors
*    dl_stdcolor_init ... initializes the standard color table
*    dl_stdcolor_name ... returns the standard color name of an entry
*    dl_stdcolor_def .... returns the defined RGB value of an entry
*    dl_stdcolor_act .... returns the actual RGB value used
*    dl_stdcolor_index .. returns a standard color index given a name
*    dl_stdcolor_pixel .. returns a "pixel" of color for display (X11 only)
*
****************************************************************************
*  Minimal stubs follow.
****************************************************************************/

#include "dl_defs.h"

static DL_RECT  rect = { 0., 0., 100., 100. };
static DL_PIXEL pix  = { 100, 100 };

void      dl_beginscreen(void)		{ }
void      dl_endscreen(void)		{ }
void      dl_flush(void)			{ }
void      dl_setcellcount(int c)	{ }
void      dl_setcellrc(void)		{ }
int       dl_cellcount(void)		{ return 1; }
int       dl_cellrows(void)			{ return 1; }
int       dl_cellcols(void)			{ return 1; }
void      dl_setcell(int c)		{ }
int       dl_cell(void)			{ return 1; }
void      dl_setga(int ga)		{ }
int       dl_ga(void)			{ return 0; }
int       dl_colormode(void)		{ return DL_COLORMODE_MONOCHROME; }
void      dl_setlinewidth(int w)	{ }
void      dl_setlinestyle(int s)	{ }
void      dl_setpixels(DL_PIXEL *p)	{ }
DL_PIXEL  dl_pixels(void)         		{ return pix; }
void      dl_setbounds(DL_RECT *r)	{ }
void      dl_fitbounds(DL_RECT *r)      { }
void      dl_fixbounds(int fixed)	{ }
DL_RECT   dl_bounds(void)         		{ return rect; }
void      dl_setaspect(float a)		{ }
float     dl_paspect(void)         		{ return 1.0; }
void      dl_moveto(DL_POINT *p)	{ }
void      dl_drawto(DL_POINT *p)        { }
void      dl_drawbox(DL_RECT *r)        { }
void      dl_drawoval(DL_RECT *r)       { }
DL_RECT   dl_labelbounds(DL_LABEL *l)   { return rect; }
void      dl_drawlabel(DL_LABEL *l)     { }
void      dl_fitlabel(DL_LABEL *l, DL_RECT *box)	 { }
int       dl_stdcolor_count(void)				 { return 1; }
int       dl_stdcolor_init(void *dpy, int scr)		 { return 1; }
char     *dl_stdcolor_name(int i)			 { return "stub"; }
int       dl_stdcolor_def(int i, int *r, int *g, int *b) { return 1; }
int       dl_stdcolor_act(int i, int *r, int *g, int *b) { return 1; }
int       dl_stdcolor_index(char *name)			 { return 1; }
int       dl_stdcolor_pixel(int i)			 { return 1; }
