c======================================================================
c  This source code is public domain, and may be freely distributed,
c  modified, and used for any purpose.  IT COMES WITH ABSOLUTELY NO
c  WARRANTY OF ANY KIND.
c======================================================================
c  du_mf.f - return molecular formula of object as string object
c
c  The molecular formula is printed in the order C, H, then
c  alphabetically by atomic symbol (this order is coded in mford[]).
c
c  Although usually used with objects of TYP_MOLECULE, this works for
c  any atom-containing object (i.e. molecules, atoms, bonds, cycles,
c  substructs, paths, streams, and sequences).
c
c  Standard atomic symbols are assumed for first 105 elements.
c  (Symbols used by the Daylight Toolkit for elements 100-105 are:
c  Fm, Md, No, Lr, Rf, Ha.)
c
c  This limits molecular formulas to (a generous) 512 characters.
c----------------------------------------------------------------------
      subroutine du_mf( ob, mf, mflen )
      integer ob
      integer mflen
      integer     MAXMF 
      parameter ( MAXMF = 512 )
      character*(MAXMF) mf
      include 'dt_f_smiles.inc'
c----------------------------------------------------------------------
c  Declare handle variables (in Fortran, integers).  Note that
c  elatom(0) is the wildcard element.
c----------------------------------------------------------------------
      integer            atoms, atom, elatom(0:105)
c----------------------------------------------------------------------
c  Declare other variables
c----------------------------------------------------------------------
      integer            i, elem, symlen, elfreq(0:105), lens
      character*(2)      sym
      character*(4)      elfreqstr
      logical            ok
c----------------------------------------------------------------------
c  Declare functions used.
c----------------------------------------------------------------------
      integer dt_f_stream, dt_f_next, dt_f_isohydro
      integer dt_f_imp_hcount, dt_f_symbol, dt_f_number
      logical dt_f_dealloc
c----------------------------------------------------------------------
c  The mford() array defines the order of elements in the mf.  Note
c  that mford(106) is the "unknown element" of "atomic number" zero.
c----------------------------------------------------------------------
      integer mford(106)
      data (mford(i),i=1,106) /6,  1, 89, 47, 13, 95, 18, 33, 85, 79,
     &                         5, 56,  4, 83, 97, 35, 20, 48, 58, 98,
     &                        17, 96, 27, 24, 55, 29, 66, 68, 99, 63,
     &                         9, 26,100, 87, 31, 64, 32,105,  2, 72,
     &                        80, 67, 53, 49, 77, 19, 36, 57,  3,103,
     &                        71,101, 12, 25, 42,  7, 11, 41, 60, 10,
     &                        28,102, 93,  8, 76, 15, 91, 82, 46, 61,
     &                        84, 59, 78, 94, 88, 37, 75,104, 45, 86,
     &                        44, 16, 51, 21, 34, 14, 62, 50, 38, 73,
     &                        65, 43, 52, 90, 22, 81, 69, 92, 23, 74,
     &                        54, 39, 70, 30, 40, 0/
c----------------------------------------------------------------------
c  Zero elfreq array
c----------------------------------------------------------------------
      do 5 i=0,105
         elfreq(i) = 0
5     continue
c----------------------------------------------------------------------
c  Stream atoms from ob if possible; if not return NULL_OB.
c----------------------------------------------------------------------
      atoms = dt_f_stream(ob, TYP_ATOM)
      if (atoms .eq. NULL_OB) then
         mf = ''
         mflen = 0
         return
      endif
c----------------------------------------------------------------------
c  Define elatom(1) to be a hydrogen atom object.
c----------------------------------------------------------------------
      elatom(1) = dt_f_isohydro()
c----------------------------------------------------------------------
c  For each atom, assign atom handle to elatom(elem) array and
c  increment elfreq(elem), and also elfreq(1) for implicit hydrogens.
c----------------------------------------------------------------------
10    continue
      atom = dt_f_next(atoms)
      if (atom .eq. NULL_OB) then
         go to 100
      else
         elem = dt_f_number(atom)
         elatom(elem) = atom
         elfreq(elem) = elfreq(elem) + 1
         elfreq(1) = elfreq(1) + dt_f_imp_hcount(atom)
      endif
      go to 10
100   continue
      ok = dt_f_dealloc(atoms)
c----------------------------------------------------------------------
c  Initialize mf, mflen.
c----------------------------------------------------------------------
      mf = ''
      mflen = 0
c----------------------------------------------------------------------
c  For all 105 real elements and the wildcard element, compose the 
c  mf in mford() order.
c----------------------------------------------------------------------
      do 200 i=1,106
         elem = mford(i)
         if (elfreq(elem) .gt. 0) then
            symlen = dt_f_symbol(elatom(elem), sym)
            mf(mflen+1:) = sym(:symlen)
            mflen = mflen + symlen
            if (elfreq(elem) .ne. 1) then
               elfreqstr = ''
               write (elfreqstr, '(I4)') elfreq(elem)
               lens = 4
               call du_leftstr(elfreqstr, lens)
               mf(mflen + 1:) = elfreqstr
               mflen = mflen + lens
            endif
         endif
200   continue
      return
      end
c======================================================================
c  du_leftstr.f - left-justify string
c----------------------------------------------------------------------
      subroutine du_leftstr( str, lens )
      character*(*) str
      integer lens, i
c----------------------------------------------------------------------
      i = 0
10    continue
      if (str(1:1) .ne. ' ') then
         return
      else
         str = str(2:)
         lens = lens - 1
      endif
      go to 10
      end
